@@ -20,6 +20,7 @@ class Vault(BaseModel):
 class ContextUpdater:
     states = {}  # state_name: state_func
     exit_phrases = ['exit', 'выход', 'хватит', 'остановись']
+    vault = None
 
     def __init__(self, data: SkillRequestType,
                  dictionary: Type[Dictionary] = None,
@@ -71,7 +72,8 @@ class ContextUpdater:
             else:
                 self.states[state](self)
         # Save vault updated data
-        self.context['__vault__'] = self.vault.dict()
+        if self.vault:
+            self.context['__vault__'] = self.vault.dict()
 
     def execute_now(self, func: Callable) -> None:
         self.next_state = func
